@@ -446,8 +446,8 @@ int stream_stop_sending(ngtcp2_conn *conn, int64_t stream_id,
 } // namespace
 
 namespace {
-int extend_max_streams_bidi(ngtcp2_conn *conn, uint64_t max_streams,
-                            void *user_data) {
+int extend_max_local_streams_bidi(ngtcp2_conn *conn, uint64_t max_streams,
+                                  void *user_data) {
   auto c = static_cast<Client *>(user_data);
 
   if (c->on_extend_max_streams() != 0) {
@@ -668,8 +668,8 @@ int Client::init(int fd, const Address &local_addr, const Address &remote_addr,
       stream_close,
       nullptr, // recv_stateless_reset
       ngtcp2_crypto_recv_retry_cb,
-      extend_max_streams_bidi,
-      nullptr, // extend_max_streams_uni
+      extend_max_local_streams_bidi,
+      nullptr, // extend_max_local_streams_uni
       rand,
       get_new_connection_id,
       nullptr, // remove_connection_id
@@ -2211,10 +2211,15 @@ int parse_uri(Request &req, const char *uri) {
 
   req.scheme = get_string(uri, u, UF_SCHEMA);
 
-  req.authority = get_string(uri, u, UF_HOST);
-  if (util::numeric_host(req.authority.c_str(), AF_INET6)) {
-    req.authority = '[' + req.authority + ']';
+  auto host = std::string(get_string(uri, u, UF_HOST));
+  if (util::numeric_host(host.c_str(), AF_INET6)) {
+    req.authority = '[';
+    req.authority += host;
+    req.authority += ']';
+  } else {
+    req.authority = std::move(host);
   }
+
   if (u.field_set & (1 << UF_PORT)) {
     req.authority += ':';
     req.authority += get_string(uri, u, UF_PORT);
