@@ -404,8 +404,8 @@ int stream_close(ngtcp2_conn *conn, uint32_t flags, int64_t stream_id,
 } // namespace
 
 namespace {
-int extend_max_streams_bidi(ngtcp2_conn *conn, uint64_t max_streams,
-                            void *user_data) {
+int extend_max_local_streams_bidi(ngtcp2_conn *conn, uint64_t max_streams,
+                                  void *user_data) {
   auto c = static_cast<Client *>(user_data);
 
   if (c->on_extend_max_streams() != 0) {
@@ -557,14 +557,7 @@ int recv_new_token(ngtcp2_conn *conn, const uint8_t *token, size_t tokenlen,
     return 0;
   }
 
-  auto f = BIO_new_file(config.token_file.data(), "w");
-  if (f == nullptr) {
-    std::cerr << "Could not write token in " << config.token_file << std::endl;
-    return 0;
-  }
-
-  PEM_write_bio(f, "QUIC TOKEN", "", token, tokenlen);
-  BIO_free(f);
+  util::write_token(config.token_file, token, tokenlen);
 
   return 0;
 }
@@ -617,8 +610,8 @@ int Client::init(int fd, const Address &local_addr, const Address &remote_addr,
       stream_close,
       nullptr, // recv_stateless_reset
       ngtcp2_crypto_recv_retry_cb,
-      extend_max_streams_bidi,
-      nullptr, // extend_max_streams_uni
+      extend_max_local_streams_bidi,
+      nullptr, // extend_max_local_streams_uni
       rand,
       get_new_connection_id,
       nullptr, // remove_connection_id
@@ -1194,6 +1187,7 @@ int create_sock(Address &remote_addr, const char *addr, const char *port) {
 
   remote_addr.len = rp->ai_addrlen;
   memcpy(&remote_addr.su, rp->ai_addr, rp->ai_addrlen);
+  remote_addr.ifindex = 0;
 
   return fd;
 }
